@@ -386,7 +386,7 @@ class UserFunctor(ABC, Datum):
     #    first: this
     #    second: the local config file
     #    third: the executor (args > config > environment)
-    # RETURNS the value of the given variable or None.
+    # RETURNS the value of the given variable or default.
     def Fetch(this,
         varName,
         default=None,
@@ -511,8 +511,13 @@ class UserFunctor(ABC, Datum):
 
     #Copy a file or folder from source to destination.
     #This really shouldn't be so hard...
-    def Copy(this, source, destination):
-        source = str(Path(source).resolve())
+    #root allows us to interpret '/' as something other than the top of the filesystem.
+    def Copy(this, source, destination, root='/'):
+        if (source.startswith('/')):
+            source = str(Path(root).joinpath(source).resolve())
+        else:
+            source = str(Path(source).resolve())
+        
         destination = str(Path(destination).resolve())
         
         Path(os.path.dirname(os.path.abspath(destination))).mkdir(parents=True, exist_ok=True)
@@ -724,7 +729,7 @@ class Executor(DataContainer, UserFunctor):
     #    second: extra arguments provided to *this.
     #    third: the config file, if provided.
     #    fourth: the environment (if enabled).
-    # RETURNS the value of the given variable or None.
+    # RETURNS the value of the given variable or default.
     def Fetch(this, varName, default=None, enableThis=True, enableArgs=True, enableConfig=True, enableEnvironment=True):
         logging.debug(f"Fetching {varName}...")
 
